#!/bin/sh
#
# Resilio Sync service
. /etc/service.subr

prog_dir=`dirname \`realpath $0\``

name="ResilioSync"
version="2.6.2"
description="Sync uses peer-to-peer technology to provide fast, private file sharing for teams and individuals. By skipping the cloud, transfers can be significantly faster because files take the shortest path between devices. Sync does not store your information on servers in the cloud, avoiding cloud privacy concerns. Install Sync on a NAS device to automatically keep all your folders in Sync continuously available through your NAS."

framework_version="2.0"
pidfile="/tmp/DroboApps/${name}/pid.txt"
logfile="/tmp/DroboApps/${name}/log.txt"
statusfile="/tmp/DroboApps/${name}/status.txt"
errorfile="/tmp/DroboApps/${name}/error.txt"

daemon="${prog_dir}/sbin/rslsync"
conffile="${prog_dir}/etc/resilio-sync.conf"
avahifile="${prog_dir}/etc/resilio-sync.service"

btsyncservice="/mnt/DroboFS/Shares/DroboApps/BitTorrent_Sync/service.sh"
btsyncstorage="/mnt/DroboFS/Shares/DroboApps/BitTorrent_Sync/data"
resiliostorage="/mnt/DroboFS/Shares/DroboApps/ResilioSync/data"

_mount_tmp() {
  grep -q ^tmpfs /proc/mounts 2> /dev/null
  if [ $? -ne 0 ]; then
    mount -t tmpfs tmpfs /tmp 1> /dev/null 2>&1
  fi
  mkdir -p `dirname ${pidfile}` 1> /dev/null 2>&1
}

_create_config() {
  cp "${conffile}.default" "${conffile}" 1>> "${logfile}" 2>&1
}

_avahi_update() {
  local port
  port=`grep ".*\"listen\".*:.*," etc/resilio-sync.conf.default | sed "s/.*:\(.*\)\".*/\1/"`
  if [ -z "${port}" ]; then
    port=8888
  fi
  sed -i -e "s|<port>.*</port>|<port>${port}</port>|" "${avahifile}" 1>> "${logfile}" 2>&1
  ln -fs "${avahifile}" "/etc/avahi/services/" 1>> "${logfile}" 2>&1
  /sbin/avahi-daemon -r 1>> "${logfile}" 2>&1
}

_avahi_clear() {
  rm -f "/etc/avahi/services/`basename ${avahifile}`" 1>> "${logfile}" 2>&1
  /sbin/avahi-daemon -r 1>> "${logfile}" 2>&1
}

start() {
  _mount_tmp

  if [ -f ${btsyncservice} ]; then
    ${btsyncservice} stop
  fi

  if [ -d ${btsyncstorage} ] && [ ! -f ${resiliostorage}/sync.dat ]; then
    rm -rf ${resiliostorage}
    mv ${btsyncstorage} ${resiliostorage}
  fi

  _create_config
  HOME="/mnt/DroboFS/Shares/Public" "${daemon}" --config "${conffile}" >> "${logfile}" 2>&1
  _avahi_update
}

_stop_service() {
  _avahi_clear
  stop_service
}

case "$1" in
  start)   start_service ;;
  stop)    _stop_service ;;
  restart) _stop_service ; sleep 3 ; start_service ;;
  status)  status ;;
  *) echo "Usage: $0 [start|stop|restart|status]" ; exit 1 ;;
esac
